@@ -11,9 +11,9 @@ use HTML::Entities qw(encode_entities);
 use Scalar::Util qw(looks_like_number blessed reftype refaddr);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2024-03-16'; # DATE
+our $DATE = '2024-03-17'; # DATE
 our $DIST = 'Data-Dump-HTML-Collapsible'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our @EXPORT = qw(dd);
 our @EXPORT_OK = qw(dump);
@@ -186,7 +186,6 @@ sub _dump {
 }
 
 our $_is_dd;
-our $_is_ellipsis;
 sub _dd_or_dump {
     local %_seen_refaddrs;
     local %_subscripts;
@@ -194,7 +193,7 @@ sub _dd_or_dump {
 
     my $res;
     if (@_ > 1) {
-        die "Currently multiple arguments are not supported, plese only pass 1 argument";
+        die "Currently multiple arguments are not supported, please only pass 1 argument";
         #$res = "(" . join(",\n", map {_dump($_, '', 0)} @_) . ")";
     } else {
         $res = _dump($_[0], '', 0);
@@ -230,7 +229,7 @@ Data::Dump::HTML::Collapsible - Dump Perl data structures as HTML document with
 
 =head1 VERSION
 
-This document describes version 0.005 of Data::Dump::HTML::Collapsible (from Perl distribution Data-Dump-HTML-Collapsible), released on 2024-03-16.
+This document describes version 0.006 of Data::Dump::HTML::Collapsible (from Perl distribution Data-Dump-HTML-Collapsible), released on 2024-03-17.
 
 =head1 SYNOPSIS
 
@@ -324,8 +323,8 @@ Other data structure dumpers to (collapsible) tree: L<Data::HTML::TreeDumper>
 recursion), L<Data::TreeDumper> (L<Data::TreeDumper::Renderer::DHTML>,
 L<Data::TreeDumper::Renderer::GTK>), L<Data::Dumper::GUI>.
 
-Other data structure dumpers that outputs to HTML: L<Data::HTMLDumper>,
-L<Data::Dumper::HTML>, L<Data::Format::Pretty::HTML>.
+Other data structure dumpers that outputs to HTML: L<Data::Dump::HTML::PopUp>,
+L<Data::HTMLDumper>, L<Data::Dumper::HTML>, L<Data::Format::Pretty::HTML>.
 
 Other data structure dumpers, among others: L<Data::Dumper>, L<Data::Dump>,
 L<Data::Dump::Color>, L<Data::Dmp>, L<Data::Printer>.
